@@ -27,9 +27,6 @@ class WorkspacesAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url=f'{base_url}/api/workspace/',
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self.auth.verify
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
